/*
 *      ccard - credit card number validation
 *      Copyright (C) 2007, 2009 Peter Miller
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see
 *      <http://www.gnu.org/licenses/>.
 */

#ifndef CCARD_H
#define CCARD_H

#ifndef _
#if __STDC__
#define _(x) x
#else
#define _(x) ()
#endif
#endif

enum ccard_type_ty
{
    ccard_type_unknown,
    ccard_type_mastercard,
    ccard_type_visa,
    ccard_type_amex,
    ccard_type_diners,
    ccard_type_discover,
    ccard_type_enroute,
    ccard_type_jcb,
    ccard_type_bankcard
};
typedef enum ccard_type_ty ccard_type_ty;

enum ccard_error_ty
{
    ccard_error_none = 0,
    ccard_error_type_unknown,
    ccard_error_non_numeric,
    ccard_error_too_long,
    ccard_error_length_incorrect,
    ccard_error_checksum
};
typedef enum ccard_error_ty ccard_error_ty;


const char *ccard_type_name(ccard_type_ty);
const char *ccard_error_name(ccard_error_ty);
ccard_error_ty ccard_valid(const char *, ccard_type_ty *);

/**
  * You can tell a lot about a person by looking at their shoes, and
  * likewise, by looking at their credit card's first digit.  This
  * represents the Major Industry Identifier.
  */
const char *ccard_industry_identifier(const char *number);

#endif /* CCARD_H */
