/*
 *      ccard - credit card number validation
 *      Copyright (C) 2007, 2009 Peter Miller
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see
 *      <http://www.gnu.org/licenses/>.
 */

#define _GNU_SOURCE 1

#include <stdio.h>
#include <unistd.h>
#include <lib/ac/stdlib.h>
#include <lib/ac/string.h>

#include <lib/patchlevel.h>

#include <ccard/ccard.h>

static char *progname;


static int
suffix(const char *s1, const char *s2)
{
    int             len1;
    int             len2;

    len1 = strlen(s1);
    len2 = strlen(s2);
    return (len2 < len1 && !memcmp(s1 + len1 - len2, s2, len2));
}


static void
set_progname(char *s)
{
    for (;;)
    {
        char            *ep;

        ep = strrchr(s, '/');
        if (!ep)
            break;
        if (ep > s && !ep[1])
        {
            *ep = 0;
            continue;
        }
        s = ep + 1;
        break;
    }
    progname = s;
}


static void
print_version(void)
{
    fprintf(stderr, "%s version %s\n", progname, PATCHLEVEL);
}


int
main(int argc, char **argv)
{
    int             j;

    set_progname(argv[0]);
    for (;;)
    {
        int             c;

        c = getopt(argc, argv, "V");
        if (c == -1)
            break;
        switch (c)
        {
        case 'V':
            print_version();
            return 0;

        default:
            fprintf(stderr, "Usage: %s <number>...\n", progname);
            fprintf(stderr, "       %s -V\n", progname);
            return 1;
        }
    }
    for (j = 1; j < argc; ++j)
    {
        ccard_type_ty   type;
        ccard_error_ty  err;
        const char      *s;

        err = ccard_valid(argv[j], &type);
        if (err)
        {
            if (type != ccard_type_unknown)
            {
                fprintf
                (
                    stderr,
                    "%s: %s: %s (%s)\n",
                    progname,
                    argv[j],
                    ccard_error_name(err),
                    ccard_type_name(type)
                );
            }
            else
            {
                fprintf
                (
                    stderr,
                    "%s: %s: %s\n",
                    progname,
                    argv[j],
                    ccard_error_name(err)
                );
            }
            exit(1);
        }
        printf("\"%s\" is a", argv[j]);
        s = ccard_type_name(type);
        if (strchr("AEIOUaeiou", s[0]))
            printf("n");
        printf(" %s", s);
        if (!suffix(s, "card"))
            printf(" card");
        printf("\n");
        printf("from the %s industry\n", ccard_industry_identifier(argv[j]));
    }
    return 0;
}
